@@ -47,57 +47,73 @@ class DDLParser(Parser, Snowflake, BaseSQL, HQL, Oracle, Redshift):
             t.type = tok.sequence_reserved.get(t.value.upper(), "ID")
         return t
 
+    def tokens_not_columns_names(self, t):
+        if not self.lexer.check and t.value in tok.symbol_tokens_no_check:
+            return self.get_tag_symbol_value_and_increment(t)
+        elif "ARRAY" in t.value:
+            t.type = "ARRAY"
+            return t
+        elif not self.lexer.is_table:
+            # if is_table mean wi already met INDEX or TABLE statement and
+            # the definition already done and this is a string
+            t.type = tok.defenition_statements.get(
+                t.value.upper(), t.type
+            )  # Check for reserved word
+        elif self.lexer.last_token != "COMMA":
+            t.type = tok.common_statements.get(t.value.upper(), t.type)
+        else:
+            t.type = tok.first_liners.get(t.value.upper(), t.type)
+
+        # get tokens from other token dicts
+        t = self.process_body_tokens(t)
+
+        self.set_lexer_tags(t)
+
+        return t
+
+    def set_lexer_tags(self, t):
+        if t.type == "SEQUENCE":
+            self.lexer.sequence = True
+        elif t.type == "CHECK":
+            self.lexer.check = True
+
     def t_STRING(self, t):
         r"((\')([a-zA-Z_,`0-9:><\=\-\+.\~\%$\!() {}\[\]\/\\\"\#\*&^|?;±§@~]*)(\')){1}"
         t.type = "STRING"
         return t
 
+    def is_token_column_name(self, t):
+        """many of reserved words can be used as column name,
+        to decide is it a column name or not we need do some checks"""
+        skip_id_tokens = ["(", ")", ","]
+        return (
+            t.value not in skip_id_tokens
+            and self.lexer.is_table
+            and self.lexer.lp_open
+            and (self.lexer.last_token == "COMMA" or self.lexer.last_token == "LP")
+            and t.value.upper() not in tok.first_liners
+        )
+
     def t_ID(self, t):
         r"([0-9]\.[0-9])\w|([a-zA-Z_,0-9:><\/\=\-\+\~\%$\*'\()!{}\[\]\"\`]+)"
         t.type = tok.symbol_tokens.get(t.value, "ID")
-        skip_id_tokens = ["(", ")", ","]
         if t.type == "LP":
             self.lexer.lp_open += 1
             self.lexer.columns_def = True
             self.lexer.last_token = "LP"
             return t
 
-        elif (
-            t.value not in skip_id_tokens
-            and self.lexer.is_table
-            and self.lexer.lp_open
-            and (self.lexer.last_token == "COMMA" or self.lexer.last_token == "LP")
-            and t.value.upper() not in tok.first_liners
-        ):
+        elif self.is_token_column_name(t):
             t.type = "ID"
         else:
-            if not self.lexer.check and t.value in tok.symbol_tokens_no_check:
-                return self.get_tag_symbol_value_and_increment(t)
-            elif "ARRAY" in t.value:
-                t.type = "ARRAY"
-                return t
-            elif not self.lexer.is_table:
-                # if is_table mean wi already met INDEX or TABLE statement and
-                # the defenition already done and this is a string
-                t.type = tok.defenition_statements.get(
-                    t.value.upper(), t.type
-                )  # Check for reserved word
-            elif self.lexer.last_token != "COMMA":
-                t.type = tok.common_statements.get(t.value.upper(), t.type)
-            else:
-                t.type = tok.first_liners.get(t.value.upper(), t.type)
+            t = self.tokens_not_columns_names(t)
 
-            # get tokens from other token dicts
-            t = self.process_body_tokens(t)
+        # capitalize tokens
+        if t.type != "ID":
+            t.value = t.value.upper()
 
-            if t.type == "SEQUENCE":
-                self.lexer.sequence = True
-            if t.type == "COMMA" and self.lexer.lt_open:
-                t.type = "COMMAT"
-            if t.type == "CHECK":
-                self.lexer.check = True
-            if t.type != "ID":
-                t.value = t.value.upper()
+        if t.type == "COMMA" and self.lexer.lt_open:
+            t.type = "COMMAT"
         return self.set_last_token(t)
 
     def set_last_token(self, t):
@@ -106,19 +122,12 @@ class DDLParser(Parser, Snowflake, BaseSQL, HQL, Oracle, Redshift):
             if t.type == "RP" and self.lexer.lp_open:
                 self.lexer.lp_open -= 1
             self.lexer.last_par = t.type
-        elif t.type == "TYPE" or t.type == "DOMAIN" or t.type == "TABLESPACE":
+        elif t.type in ["TYPE", "DOMAIN", "TABLESPACE"]:
             self.lexer.is_table = False
-        elif t.type == "TABLE" or t.type == "INDEX":
+        elif t.type in ["TABLE", "INDEX"]:
             self.lexer.is_table = True
         return t
 
-    def t_newline(self, t):
-        r"\n+"
-        self.lexer.lineno += len(t.value)
-        t.type = "NEWLINE"
-        if self.lexer.paren_count == 0:
-            return t
-
     def t_error(self, t):
         raise SyntaxError("Unknown symbol %r" % (t.value[0],))
 
