@@ -1,7 +1,7 @@
 import json
 import os
 from copy import deepcopy
-from typing import Dict, List, Tuple, Union
+from typing import Dict, List, Tuple
 
 from simple_ddl_parser.output import dialects as d
 
@@ -17,9 +17,7 @@ output_modes = [
 ]
 
 
-def get_table_from_tables_data(
-    tables_dict: Dict, table_id: Tuple[str, str], statement: Dict
-) -> Dict:
+def get_table_from_tables_data(tables_dict: Dict, table_id: Tuple[str, str]) -> Dict:
     """ get table by name and schema or rise exception """
     target_table = tables_dict.get(table_id)
     if target_table is None:
@@ -32,7 +30,7 @@ def get_table_from_tables_data(
 def add_index_to_table(tables_dict: Dict, statement: Dict, output_mode: str) -> Dict:
     """ populate 'index' key in output data """
     table_id = (statement["table_name"], statement["schema"])
-    target_table = get_table_from_tables_data(tables_dict, table_id, statement)
+    target_table = get_table_from_tables_data(tables_dict, table_id)
 
     del statement["schema"]
     del statement["table_name"]
@@ -74,7 +72,7 @@ def add_alter_to_table(tables_dict: Dict, statement: Dict) -> Dict:
     """ add 'alter' statement to the table """
     table_id = (statement["alter_table_name"], statement["schema"])
 
-    target_table = get_table_from_tables_data(tables_dict, table_id, statement)
+    target_table = get_table_from_tables_data(tables_dict, table_id)
 
     if "columns" in statement:
         prepare_alter_columns(target_table, statement)
@@ -116,48 +114,63 @@ def set_alter_to_table_data(key: str, statement: Dict, target_table: Dict) -> Di
     return target_table
 
 
-def set_checks_to_table(table_data: Dict, check: Union[List, Dict]) -> Dict:
-    if isinstance(check, list):
-        check = {"constraint_name": None, "statement": " ".join(check)}
-    table_data["checks"].append(check)
+def init_table_data() -> Dict:
+    return {
+        "columns": [],
+        "primary_key": None,
+        "alter": {},
+        "checks": [],
+        "index": [],
+        "partitioned_by": [],
+        "tablespace": None,
+    }
+
+
+def process_alter_and_index_result(
+    tables_dict: Dict, table: Dict, output_mode: str
+) -> Dict:
+    if table.get("index_name"):
+        tables_dict = add_index_to_table(tables_dict, table, output_mode)
+
+    elif table.get("alter_table_name"):
+        tables_dict = add_alter_to_table(tables_dict, table)
+
+    return tables_dict
+
+
+def process_entities(tables_dict: Dict, table: Dict, output_mode: str) -> Dict:
+    """ process tables, types, sequence and etc. data """
+    table_data = init_table_data()
+    table_data = d.populate_dialects_table_data(output_mode, table_data)
+    not_table = False
+    if table.get("table_name"):
+        table_data.update(table)
+        table_data = set_unique_columns(table_data)
+    else:
+        table_data = table
+        not_table = True
+    if not not_table:
+        table_data = process_not_table_item(table_data, tables_dict)
+    table_data = normalize_ref_columns_in_final_output(table_data)
+    d.dialects_clean_up(output_mode, table_data)
     return table_data
 
 
 def result_format(
     result: List[Dict], output_mode: str, group_by_type: bool
 ) -> List[Dict]:
+    """ method to format final output after parser """
     final_result = []
     tables_dict = {}
     for table in result:
-        table_data = {
-            "columns": [],
-            "primary_key": None,
-            "alter": {},
-            "checks": [],
-            "index": [],
-            "partitioned_by": [],
-            "tablespace": None,
-        }
-        table_data = d.populate_dialects_table_data(output_mode, table_data)
-        not_table = False
-        if len(table) == 1 and "index_name" in table[0]:
-            tables_dict = add_index_to_table(tables_dict, table[0], output_mode)
-
-        elif len(table) == 1 and "alter_table_name" in table[0]:
-            tables_dict = add_alter_to_table(tables_dict, table[0])
+        # process each item in parser output
+        if "index_name" in table or "alter_table_name" in table:
+            tables_dict = process_alter_and_index_result(
+                tables_dict, table, output_mode
+            )
         else:
-            for item in table:
-                if item.get("table_name"):
-                    table_data.update(item)
-                    table_data = set_unique_columns(table_data)
-                else:
-                    table_data = item
-                    not_table = True
-                    continue
-            if not not_table:
-                table_data = process_not_table_item(table_data, tables_dict)
-            table_data = normalize_ref_columns_in_fincal_output(table_data)
-            d.dialects_clean_up(output_mode, table_data)
+            # process tables, types, sequence and etc. data
+            table_data = process_entities(tables_dict, table, output_mode)
             final_result.append(table_data)
     if group_by_type:
         final_result = group_by_type_result(final_result)
@@ -185,7 +198,7 @@ def process_not_table_item(table_data: Dict, tables_dict: Dict) -> Dict:
     return table_data
 
 
-def normalize_ref_columns_in_fincal_output(table_data: Dict) -> Dict:
+def normalize_ref_columns_in_final_output(table_data: Dict) -> Dict:
     # todo: this is hack, need to remove it
     if "references" in table_data:
         del table_data["references"]
@@ -200,23 +213,29 @@ def normalize_ref_columns_in_fincal_output(table_data: Dict) -> Dict:
     return table_data
 
 
+def set_column_unique_param(table_data: Dict, key: str) -> Dict:
+    for column in table_data["columns"]:
+        if key == "constraints":
+            unique = table_data[key].get("unique", [])
+            if unique:
+                check_in = unique["columns"]
+            else:
+                check_in = []
+        else:
+            check_in = table_data[key]
+        if column["name"] in check_in:
+            column["unique"] = True
+    return table_data
+
+
 def set_unique_columns(table_data: Dict) -> Dict:
 
     unique_keys = ["unique_statement", "constraints"]
 
     for key in unique_keys:
         if table_data.get(key, None):
-            for column in table_data["columns"]:
-                if key == "constraints":
-                    unique = table_data[key].get("unique", [])
-                    if unique:
-                        check_in = unique["columns"]
-                    else:
-                        check_in = []
-                else:
-                    check_in = table_data[key]
-                if column["name"] in check_in:
-                    column["unique"] = True
+            # get column names from unique constraints & statements
+            table_data = set_column_unique_param(table_data, key)
     if "unique_statement" in table_data:
         del table_data["unique_statement"]
     return table_data
