@@ -1,3 +1,4 @@
+import json
 import os
 import re
 from typing import Dict, List, Optional, Tuple
@@ -7,6 +8,12 @@ from ply import lex, yacc
 from simple_ddl_parser.output.common import dump_data_to_file, result_format
 from simple_ddl_parser.utils import find_first_unpair_closed_par
 
+OP_COM = "/*"
+CL_COM = "*/"
+
+IN_COM = "--"
+MYSQL_COM = "#"
+
 
 class Parser:
     """
@@ -19,7 +26,7 @@ class Parser:
         Subclass must include tokens for parser and rules
     """
 
-    def __init__(self, content) -> None:
+    def __init__(self, content: str) -> None:
         """ init parser for file """
         self.tables = []
         self.data = content.encode("unicode_escape")
@@ -28,26 +35,36 @@ class Parser:
         self.yacc = yacc.yacc(module=self, debug=False)
         self.columns_closed = False
 
-    @staticmethod
-    def pre_process_line(line: str, block_comments: List[str]) -> Tuple[str, List]:
-        OP_COM = "/*"
-        CL_COM = "*/"
-        IN_COM = "--"
-        MYSQL_COM = "#"
+    def pre_process_line(
+        self, line: str, block_comments: List[str]
+    ) -> Tuple[str, List]:
         code_line = ""
         comma_only_str = r"((\')|(' ))+(,)((\')|( '))+\B"
         line = re.sub(comma_only_str, "_ddl_parser_comma_only_str", line)
         if "(" not in line:
             line = line.replace("<", " < ").replace(">", " > ")
-        if line.strip().startswith(MYSQL_COM) or line.strip().startswith(IN_COM):
-            return code_line, block_comments
 
-        if IN_COM in line:
-            if re.search(r"((\")|(\'))+(.)*(--)+(.)*((\")|(\'))+", line):
-                return line, block_comments
+        if not (line.strip().startswith(MYSQL_COM) or line.strip().startswith(IN_COM)):
+            code_line, block_comments = self.process_inline_comments(
+                line, code_line, block_comments
+            )
+        return code_line, block_comments
+
+    @staticmethod
+    def process_in_comment(line: str):
+        if re.search(r"((\")|(\'))+(.)*(--)+(.)*((\")|(\'))+", line):
+            code_line = line
+        else:
             code_line = line.split(IN_COM)[0]
+        return code_line
+
+    def process_inline_comments(
+        self, line: str, code_line: str, block_comments: List
+    ) -> Tuple[str, List]:
+        if IN_COM in line:
+            code_line = self.process_in_comment(line)
         elif CL_COM not in line and OP_COM not in line:
-            return line, block_comments
+            code_line = line
         if OP_COM in line:
             code_line += line.split(OP_COM)[0]
             block_comments.append(OP_COM)
@@ -56,16 +73,20 @@ class Parser:
             code_line += code_line.split(CL_COM)[1]
         return code_line, block_comments
 
+    def process_regex_input(self, data):
+        regex = data.split('"input.regex"')[1].split("=")[1]
+        index = find_first_unpair_closed_par(regex)
+        regex = regex[:index]
+        data = data.replace(regex, " lexer_state_regex ")
+        data = data.replace('"input.regex"', "parse_m_input_regex")
+        self.lexer.state = {"lexer_state_regex": regex}
+        return data
+
     def pre_process_data(self, data):
         data = data.decode("utf-8")
         # todo: not sure how to workaround ',' normal way
         if "input.regex" in data:
-            regex = data.split('"input.regex"')[1].split("=")[1]
-            index = find_first_unpair_closed_par(regex)
-            regex = regex[:index]
-            data = data.replace(regex, " lexer_state_regex ")
-            data = data.replace('"input.regex"', "parse_m_input_regex")
-            self.lexer.state = {"lexer_state_regex": regex}
+            data = self.process_regex_input(data)
 
         data = (
             data.replace(",", " , ")
@@ -85,35 +106,45 @@ class Parser:
 
     def parse_data(self):
         tables = []
-        table = []
         block_comments = []
         statement = None
         data = self.pre_process_data(self.data)
         lines = data.replace("\\t", "").split("\\n")
         for num, line in enumerate(lines):
-            line, block_comments = self.pre_process_line(line, block_comments)
-            if line.replace("\n", "").replace("\t", "") or num == len(lines) - 1:
-                # to avoid issues when comma or parath are glued to column name
-                if statement is not None:
-                    statement += f" {line.strip()}"
-                else:
-                    statement = line.strip()
-                if not statement.endswith(';') and num != len(lines) - 1:
-                    continue
-                self.set_default_flags_in_lexer()
-                if statement.endswith(';'):
-                    statement = statement[:-1]
-                _parse_result = yacc.parse(statement)
 
-                if _parse_result:
-                    table.append(_parse_result)
-                if line.strip().endswith(";") or num == len(lines) - 1:
-                    if table:
-                        tables.append(table)
-                    table = []
+            line, block_comments = self.pre_process_line(line, block_comments)
+
+            line = line.strip().replace("\n", "").replace("\t", "")
+
+            if line or num == len(lines) - 1:
+                # to avoid issues when comma or parath are glued to column name
+                final_line = line.strip().endswith(";")
+                if statement is None:
+                    statement = line
+                else:
+                    statement += f" {line}"
+
+                if final_line:
+                    # end of sql operation, remove ; from end of line
+                    statement = statement[:-1]
+                elif num != len(lines) - 1:
+                    # continue combine lines in one massive
+                    continue
+
+                self.set_default_flags_in_lexer()
+
+                self.parse_statement(tables, statement)
+
                 statement = None
         return tables
 
+    @staticmethod
+    def parse_statement(tables: List, statement: str):
+        _parse_result = yacc.parse(statement)
+
+        if _parse_result:
+            tables.append(_parse_result)
+
     def set_default_flags_in_lexer(self):
         attrs = [
             "is_table",
@@ -138,6 +169,7 @@ class Parser:
         file_path: Optional[str] = None,
         output_mode: str = "sql",
         group_by_type: bool = False,
+        json_dump=False,
     ) -> List[Dict]:
         """
         dump: provide 'True' if you need to dump output in file
@@ -163,4 +195,6 @@ class Parser:
             else:
                 for table in tables:
                     dump_data_to_file(table["table_name"], dump_path, table)
+        if json_dump:
+            tables = json.dumps(tables)
         return tables
